function [lEE,a]=CalculEE(dbx,dbz,AmpX,AmpZ,lEE,a,compteur,modele,mu)
%
% function [lEE,a]=CalculEE(dbx,dbz,AmpX,AmpZ,lEE,a,compteur,modele,mu)
%
% Calcule la longueur d'onde de l'enveloppe d'nergie
% inputs :     dbx : dbx/dt provenant de openEmGui  
%              dbz : dbz/dt provenant de openEmGui
%             AmpX : Amplitude sur chaque canal de dbx/dt (max-min)
%             AmpZ : Amplitude sur chaque canal de dbz/dt (max-min)
%              lEE : Enveloppes d'nergie dja calcules
%                a : Structure contenant les parametres
%         compteur : Nombre de modeles calculs a date
%           modele : Le numro du modele pour lequel on calcule
%               mu : Constante
% outputs :    lEE : Enveloppes d'nergie calcules
%                a : Structure contenant les parametres
%
% Maxime Claprood
%
%
% Calcul de l'enveloppe d'nergie et de son niveau de bruit
%
lee=[];
EE=[dbx(:,[1:3]) sqrt(dbx(:,[4:end]).^2 + dbz(:,[4:end]).^2)];
moy=mean(a.bruit,2);
bruitEE=1/2*sqrt(moy.^2+real(hilbert(moy)).^2);
%
% Boucle pour calculer l'EE sur tous les canaux de temps
%
for t=1:15
    T=(a.TimeCh(t+5,4)-a.TimeOnOff(1))/1000;
    atheta=10*sqrt(a.para(a.para(:,1)==modele,5)*mu/(4*T));
    %
    % Calculer les attributs pour les canaux "temps longs" et "db/dt > bruit"
    %
    if and(atheta<=2.5,and(AmpX(t)>a.bruit(t+5,1),AmpZ(t)>a.bruit(t+5,2)))
        indEE=find(EE(:,t+8)>bruitEE(t+5));
        if isempty(indEE)
            lee=[lee;(t+5) 1e6];
        else
            lee=[lee;(t+5) abs(EE(indEE(end),2)-EE(indEE(1),2))];
        end
    end
end
%
% Garder les valeurs mdianes de l'EE et les poids associs a l'EE
%
lEE(compteur,1)=modele;
if isempty(lee)
    %
    % Mettre une valeur bidon et un poid nul si pas d'attribut calcul
    %
    lEE(compteur,2)=0;
    lEE(compteur,3)=1e6;
    PoidsNul=0;
else
    lEE(compteur,2)=size(lee,1);
    if size(lee,1)==1
        lEE(compteur,3)=lee(:,2);
        if isempty(lEE(lEE==1e6))
            a.w(compteur,13)=0;
        else
            PoidsNul=0;
        end
    else
        if isempty(lee(lee(:,2)<1e6,2))
            lEE(compteur,3)=1e6;
            PoidsNul=0;
        else
            lEE(compteur,3)=median(lee(lee(:,2)<1e6,2));
            a.w(compteur,13)=std(lee(lee(:,2)<1e6,2));
        end
    end
end
