% MEGATEM: Script de base contenant les appels de fonctions pour le calcul des attributs sur des modeles numriques
%
% Maxime Claprood.
%
%
clear all; close all;
%
% Parametres initiaux
%
mu=4*pi*1e-7;
NoiseLevel=0.5;     % Fraction du bruit rel a considrer
Freq=90;            % Frquence d'mission des modeles (30 ou 90Hz)
TestouMod=0;        % 0 si modeles pour batir la banque de donnes (#1 a #2100); 1 si modeles a tester (#10000 et +)
Liste=[1:2100];     % Liste des modeles a calculer les attributs
No=707;             % Nombres de modeles tests dans le fichier ParaTest, si TestouMod==1 seulement
LV=1;               % Ligne de vol a considrer
PPX=[];PPZ=[];
tau=[];lEE=[];
DBXDBZ=[];
%
% Ouverture des fichiers parametres, de temps et du bruit du MEGATEM
%
[a,repertoire]=openparameters(No,NoiseLevel,Freq,TestouMod);
%
% Calcul des attributs sur tous les modeles de "Liste"
%
compteur=0;
for modele=Liste
    modele          % Compteur pour indiquer a l'usager ou le programme est rendu
    PoidsNul=1;     % 1 = valeur initiale. Si == 0, on met des poids nuls au modele  
    %
    % Ouverture des fichiers et calcul des amplitudes
    %
    [DBX,DBZ,dbx,dbz]=openEmGui(modele,repertoire,29,151,4,150,LV);
    AmpX=(max(dbx(:,9:end))-min(dbx(:,9:end)))';
    AmpZ=(max(dbz(:,9:end))-min(dbz(:,9:end)))';
    %
    % Calcul des attributs
    % Amplitudes en dbx et dbz/dt doivent etre > bruit pour au mois 1 canal de temps
    %
    if(and(sum(AmpX>a.bruit(6:end,1))>0,sum(AmpZ>a.bruit(6:end,2))>0))
        compteur=compteur+1;
        %
        % Calcul de la constante de temps
        %
        [tau]=TAU(DBZ,dbz,AmpZ,tau,a,compteur,modele,mu);
        % 
        % Calcul des attributs en dbx/dt
        %
        [PPX,a]=PicaPicX(dbx,AmpX,AmpZ,PPX,a,compteur,modele,mu);
        % 
        % Calcul des attributs en dbz/dt
        %
        [PPZ,a]=PicaPicZ(dbz,AmpX,AmpZ,PPZ,a,compteur,modele,mu);
        % 
        % Calcul de la longueur d'onde du champ EM total (sqrt(dbx+dbz))
        %
        [lEE,a]=CalculEE(dbx,dbz,AmpX,AmpZ,lEE,a,compteur,modele,mu);
    end
    %
    % Met tous les poids a 0 si le calcul des attributs sur 1 modele n'est pas bien dfini
    %
    if PoidsNul==0
        a.w(compteur,[2:13])=0;
    end
    %
    % Afficher graphiques
    %
    figure(modele)
    set(figure(modele),'Color',[1 1 1])
    set(figure(modele),'Position',[10 40 1000 650])
	subplot(211)
	plot(dbx(:,2),dbx(:,[11:2:end]),'r.');
    axis([1000 2000 -20 200])
    title(['Modele : ',int2str(a.para(a.para(:,1)==modele,[2:6]))],'fontweight','bold','fontsize',12)
	ylabel('dbx/dt (nT/s)','fontweight','bold','fontsize',12)
	subplot(212)
	plot(dbz(:,2),dbz(:,[11:2:end]),'r.');
    axis([1000 2000 -200 100])
    ylabel('dbz/dt (nT/s)','fontweight','bold','fontsize',12)
end
tauEE=[tau lEE(:,[2,3])];
%
% Calcul de l'attribut crois (dbx/dt vs dbz/dt)
%
if isempty(PPZ)
else
    DBXDBZ(:,1)=PPX(:,1);
    DBXDBZ(:,2)=PPX(:,3)./PPZ(:,3);
end
DBXDBZ(or(PPX(:,3)==1e6,PPZ(:,3)==1e6),2)=1e6;
%
% Initialisation des variables descriptives
%
a.PPXName=char('Modele','Nbre de canaux','|Px1-Px2|','|Px1/Px2|');
a.PPZName=char('Modele','Nbre de canaux','|Pz1-Pz2|','|Pz1-Pz3|','|Pz2-Pz3|','(Pz1/Pz2)','(Pz1/Pz3)','(Pz2/Pz3)','|(Pz1-Pz2)/(Pz1-Pz3)|');
a.tauEEName=char('Modele','Nbre de canaux (tau)','tau','r2 de tau','Nbre de canaux (EE)','EE-Lambda');
a.dbxdbzName=char('Modele','(Px1-Px2)/(Pz1-Pz2)');
a.wName=char('Modele','Nb_Ch>=Bruit/Nb_Total_Ch','Amp/Noise','Col 4:13 : Std des attibuts');
%
% Sauvegarde des donnes dans fichier "Tests.mat" ou "VARX.mat" ou VMSdata
%
% if TestouMod==1
%     load Tests
%     PPXtest=[PPXtest;PPX];
%     PPZtest=[PPZtest;PPZ];
%     tauEEtest=[tauEEtest;tauEE];
%     DBXDBZtest=[DBXDBZtest;DBXDBZ];
%     atest=a;
%     save Tests atest PPXtest PPZtest tauEEtest DBXDBZtest;
% else
%     save VARX a PPX PPZ tauEE DBXDBZ;
% end
% %
% % Pour sauvegarder dans VMSdata
% %
% PPX(:,2)=LV;
% PPZ(:,2)=LV;
% tauEE(:,2)=LV;
% load VMSdata
% PPXtest=[PPXtest;PPX];
% PPZtest=[PPZtest;PPZ];
% tauEEtest=[tauEEtest;tauEE];
% DBXDBZtest=[DBXDBZtest;DBXDBZ];
% save VMSdata atest PPXtest PPZtest tauEEtest DBXDBZtest;
