function [PPX,a]=PicaPicX(dbx,AmpX,AmpZ,PPX,a,compteur,modele,mu)
%
% function [PPX,a]=PicaPicX(dbx,AmpX,AmpZ,PPX,a,compteur,modele,mu)
%
% Calculer les caractristiques du lev dbx/dt (ratio et distance pic-a-pic)
% inputs :     dbx : dbx/dt provenant de openEmGui
%             AmpX : Amplitude sur chaque canal de dbx/dt
%             AmpZ : Amplitude sur chaque canal de dbz/dt
%              PPX : Caractristiques dja calcules sur dbx/dt
%                a : Structure contenant les parametres
%         compteur : Compteur
%           modele : Le numro du modele pour lequel on calcule
%               mu : Constante
% outputs :    PPX : Caractristiques sur dbx/dt
%                a : Structure contenant les parametres
%
% Maxime Claprood.
%
%
% Calcul des drives pour observer les changements de pentes
%
diffdbx=diff(dbx(:,[9:end]),1,1);
signdbx=sign(diffdbx);
picx=[];ppx=[];
Nb=0;
%
% Boucle pour calculer les pics sur chaque canal de temps en dbx/dt
%
for t=1:15
    T=(a.TimeCh(t+5,4)-a.TimeOnOff(1))/1000;
    atheta=10*sqrt(a.para(a.para(:,1)==modele,5)*mu/(4*T));
    if atheta<=2.5
        Nb=Nb+1;
    end
    %
    % Calculer les attributs pour les canaux "temps longs" et "db/dt > bruit"
    %
    if and(atheta<=2.5,and(AmpX(t)>a.bruit(t+5,1),AmpZ(t)>a.bruit(t+5,2)))
        %
        % Trouver les changements de signe de la drive
        %
        ind=find(signdbx(1:end-1,t)-signdbx(2:end,t)>0);
        IND=find(abs(dbx(ind,t+8))>0.05);
        picx=[picx;(t+5)*ones(length(IND),1) dbx(ind(IND)+1,[2,t+8])];
        bidon=picx(picx(:,1)==t+5,:);
        %
        % On calcule les caractristiques si on a au moins 2 pics
        %        
        z=size(bidon,1);
        switch z
        case 0
        case 1
        case 2
            ppx=[ppx;(t+5) z abs(bidon(1,2)-bidon(2,2)) abs(bidon(bidon(:,2)==max(bidon(:,2)),3)/bidon(bidon(:,2)==min(bidon(:,2)),3))];
        otherwise
            bidon1=bidon(abs(bidon(:,3))==max(abs(bidon(:,3))),:);
            bidon=bidon(bidon(:,3)~=bidon1(3),:);
            bidon2=bidon(abs(bidon(:,3))==max(abs(bidon(:,3))),:);
            bidon=[bidon1;bidon2];
            ppx=[ppx;(t+5) z abs(bidon(1,2)-bidon(2,2)) abs(bidon(bidon(:,2)==max(bidon(:,2)),3)/bidon(bidon(:,2)==min(bidon(:,2)),3))];
        end
    end
end
%
% Garder les valeurs mdianes des caractristiques et les poids associs
%
PPX(compteur,1)=modele;
a.w(compteur,1)=modele;
if isempty(ppx)
    %
    % Mettre une valeur bidon et un poid nul si pas d'attribut calcul
    %
    PPX(compteur,2)=0;
    PPX(compteur,[3,4])=1e6;
    PoidsNul=0;
else
    PPX(compteur,2)=size(ppx,1);        % Nombre de canaux utiliss dans les calculs
    a.w(compteur,2)=size(ppx,1)/Nb;     % Poids : # Canaux utiliss / # total Canaux
    XX=AmpX(ppx(:,1)-5);
    ZZ=AmpZ(ppx(:,1)-5);
    Nx=a.bruit(ppx(:,1),1);
    Nz=a.bruit(ppx(:,1),1);
    a.w(compteur,3)=mean(XX./Nx+ZZ./Nz);    % Poids : Amplitude / bruit
    if size(ppx,1)==1
        PPX(compteur,[3,4])=ppx(:,[3,4]);
        a.w(compteur,[4,5])=0;
    else
        for i=3:4
            PPX(compteur,i)=median(ppx(ppx(:,i)<1e6,i));
            a.w(compteur,i+1)=std(ppx(ppx(:,i)<1e6,i));
        end
    end
end