function [PPZ,a]=PicaPicZ(dbz,AmpX,AmpZ,PPZ,a,compteur,modele,mu)
%
% function [PPZ,a]=PicaPicZ(dbz,AmpX,AmpZ,PPZ,a,compteur,modele,mu)
%
% Calculer les caractristiques du lev dbz/dt (ratio et distance pic-a-pic)
% inputs :     dbz : dbz/dt provenant de openEmGui
%             AmpX : Amplitude sur chaque canal de dbx/dt (max-min)
%             AmpZ : Amplitude sur chaque canal de dbz/dt (max-min)
%              PPZ : Caractristiques dja calcules sur dbz/dt
%                a : Structure contenant les parametres
%         compteur : Nombre de modeles calculs a date
%           modele : Le numro du modele pour lequel on calcule
%               mu : Constante
% outputs :    PPZ : Caractristiques sur dbz/dt
%                a : Structure contenant les parametres
% Maxime Claprood.
%
%
% Calcul des drives pour observer les changements de pentes
%
diffdbz=diff(dbz(:,[9:end]),1,1);
signdbz=sign(diffdbz);
picz=[];ppz=[];
%
% Boucle pour calculer les pics sur chaque canal de temps en dbz/dt
%
for t=1:15
    T=(a.TimeCh(t+5,4)-a.TimeOnOff(1))/1000;
    atheta=10*sqrt(a.para(a.para(:,1)==modele,5)*mu/(4*T));
    %
    % Calculer les attributs pour les canaux "temps longs" et "db/dt > bruit"
    %
    if and(atheta<=2.5,and(AmpX(t)>a.bruit(t+5,1),AmpZ(t)>a.bruit(t+5,2)))
        %
        % Trouver les changements de signe de la drive
        %
        indz=find(signdbz(1:end-1,t)-signdbz(2:end,t)~=0);
        INDZ=find(abs(dbz(indz,t+8))>0.1);
        picz=[picz;(t+5)*ones(length(INDZ),1) dbz(indz(INDZ)+1,[2,t+8])];
        bidonz=picz(picz(:,1)==t+5,:);
        zz=size(bidonz,1);
        %
        % On calcule les caractristiques si on a au moins 2 pics
        %        
        switch zz
        case 0
        case 1
        case 2
            %
            % On vrifie quels pics on a pour calculer les attributs qu'on peut
            %
            if signdbz(indz(INDZ(1)),t)==signdbz(indz(INDZ(2)),t)
                if signdbz(indz(INDZ(1)),t)>0
                    p1=bidonz(bidonz(:,2)==max(bidonz(:,2)),:);
                    p2=bidonz(bidonz(:,2)==min(bidonz(:,2)),:);
                    ppz=[ppz;(t+5) zz abs(p1(2)-p2(2)) 1e6 1e6 abs(p1(3)/p2(3)) 1e6 1e6 1e6];
                end                    
            else
                if signdbz(indz(INDZ(1)),t)>0
                    p2=bidonz(1,:);
                    p3=bidonz(2,:);
                    ppz=[ppz;(t+5) zz 1e6 1e6 abs(p3(2)-p2(2)) 1e6 1e6 abs(p2(3)/p3(3)) 1e6];
                else
                    p1=bidonz(2,:);
                    p3=bidonz(1,:);
                    ppz=[ppz;(t+5) zz 1e6 abs(p1(2)-p3(2)) 1e6 1e6 abs(p1(3)/p3(3)) 1e6 1e6];
                end
            end
        case 3
            p1=bidonz(bidonz(:,2)==max(bidonz(:,2)),:);
            p2=bidonz(bidonz(:,2)==min(bidonz(:,2)),:);
            p3=bidonz(and(bidonz(:,2)~=p1(1,2),bidonz(:,2)~=p2(1,2)),:);
            ppz=[ppz;(t+5) zz abs(p1(2)-p2(2)) abs(p1(2)-p3(2)) abs(p3(2)-p2(2)) abs(p1(3)/p2(3)) abs(p1(3)/p3(3)) abs(p2(3)/p3(3)) abs((p1(2)-p2(2))/(p1(2)-p3(2)))];
        otherwise
            P1=bidonz(bidonz(:,3)==max(bidonz(:,3)),:);
            bidonz=bidonz(bidonz(:,3)~=max(bidonz(:,3)),:);
            P2=bidonz(bidonz(:,3)==max(bidonz(:,3)),:);
            P3=bidonz(or(and(bidonz(:,2)>P1(:,2),bidonz(:,2)<P2(:,2)),and(bidonz(:,2)<P1(:,2),bidonz(:,2)>P2(:,2))),:);
            PP=[P1;P2;P3];
            p1=PP(PP(:,2)==max(PP(:,2)),:);
            p2=PP(PP(:,2)==min(PP(:,2)),:);
            if isempty(P3)
                ppz=[ppz;(t+5) zz abs(p1(2)-p2(2)) 1e6 1e6 abs(p1(3)/p2(3)) 1e6 1e6 1e6];
            else
                p3=PP(and(PP(:,2)~=p1(1,2),PP(:,2)~=p2(1,2)),:);
                ppz=[ppz;(t+5) zz abs(p1(2)-p2(2)) abs(p1(2)-p3(2)) abs(p3(2)-p2(2)) abs(p1(3)/p2(3)) abs(p1(3)/p3(3)) abs(p2(3)/p3(3)) abs((p1(2)-p2(2))/(p1(2)-p3(2)))];
            end
        end
    end
end
%
% Garder les valeurs mdianes des caractristiques (si plus d'1 canal utilis)
%
PPZ(compteur,1)=modele;
if isempty(ppz)
    %
    % Mettre une valeur bidon et un poid nul si pas d'attribut calcul
    %
    PPZ(compteur,2)=0;
    PPZ(compteur,[3:9])=1e6;
    PoidsNul=0;
else
    PPZ(compteur,2)=size(ppz,1);
    if size(ppz,1)==1
        PPZ(compteur,[3:9])=ppz(:,[3:9]);
        if isempty(ppz(ppz==1e6))
            a.w(compteur,[6:12])=0;
        else
            PoidsNul=0;
        end
    else
        for i=3:9
            if isempty(ppz(ppz(:,i)<1e6,i))
                PPZ(compteur,i)=1e6;
                PoidsNul=0;
            else
                PPZ(compteur,i)=median(ppz(ppz(:,i)<1e6,i));
                a.w(compteur,i+3)=std(ppz(ppz(:,i)<1e6,i));
            end
        end
    end
end