function [tau]=TAU(DBZ,dbz,AmpZ,tau,a,compteur,modele,mu)
%
% function [tau]=TAU(DBZ,dbz,AmpZ,tau,a,compteur,modele,mu)
%
% Calcul de la constante de temps de la plaque sur dbz/dt
%
% inputs :     DBZ : dbz/dt total
%              dbz : dbz/dt de la plaque seule
%             AmpZ : Amplitude en dbz/dt sur tous les canaux
%              tau : Constante de temps calcule
%                a : Structure contenant les parametres de modlisation
%         compteur : Simple compteur
%           modele : Le numro du modele pour lequel on calcule
%               mu : Constante
% outputs :    tau : Constante de temps calcule
%
% Maxime Claprood, 2005
%
%
% Initialisation des variables
%
i=0;
r2=0;
taull=1e10;
oldr2=-1;
Decrois=[];
%
% Calculer "tau" a la position dbz/dt max sur Ch#8
%
posmax=DBZ(DBZ(:,11)==max(abs(DBZ(:,11))),2);   % Position ou dbz/dt est max
total=DBZ(DBZ(:,2)==posmax,[9:end])';           % dbz/dt total
medz=median(DBZ([1:20,end-20:end],[4:end]))';
plaque=dbz(dbz(:,2)==posmax,[9:end])';          % dbz/dt de la plaque seule
decrois=[a.TimeCh([6:20],4)-a.TimeOnOff(1) total medz(6:end) plaque];
%
% Garder les canaux temps longs seulement (atheta < 2.5)
%
atheta=10*sqrt(a.para(a.para(:,1)==modele,5)*mu./(4*decrois(:,1)/1000));
decrois=[decrois AmpZ a.bruit([6:20],2)];
decrois=decrois(atheta<2.5,:);
%
% Garder les canaux de temps dont l'amplitude est plus leve que le bruit
%
for i=1:size(decrois,1)
    if decrois(i,5)>decrois(i,6)
        Decrois(i,:)=decrois(i,[1:4]);
    else 
        break
    end
end
%
% Garder les valeurs positives
%
if isempty(Decrois)
else
    Decrois=Decrois(Decrois(:,4)>=0,:);
end
%
% Estime tau par rgression linaire
%
i=0;
while and(taull>0,r2>=oldr2)
    oldr2=r2;
    i=i+1;
    Decrois=Decrois([i:end],:);
    if size(Decrois,1)>=3
        [bll,ycll,ell,scll,r2ll,s2bll,rbll]=regres(log(Decrois(:,4)),Decrois(:,1),1);
        taull=-1/bll(1);
        NbreCh=size(Decrois,1);
    else
        taull=1e6;
        r2ll=1e6;
        NbreCh=0;
        PoidsNul=0;
    end
    r2=r2ll;
    if r2>=0.95
        break;
    end
end
tau(compteur,1)=modele;
tau(compteur,2)=NbreCh;
tau(compteur,3)=taull;
tau(compteur,4)=r2ll;
