function [DBX,DBZ,dbx,dbz]=openEmGui(modele,repertoire,NbCol,NbRg,NbLine,LineSep,LV)
%
% function [DBX,DBZ,dbx,dbz]=openEmGui(modele,repertoire,NbCol,NbRg,NbLine,LineSep)
%
% openEmGui : Ouvre le fichier de sortie provenant des logiciels de CSIRO
%             Interpole les donnes aux 2m et garde la 1ere ligne de vol
% inputs  : modele : No du modele a ouvrir (nom des modeles doit etre model#)
%       repertoire : Nom du rpertoire dans lequel sont les modeles 
%            NbCol : Nombre de colonnes du fichier EmGui
%             NbRg : Nombre de points de mesure d'une ligne de vol
%           NbLine : Nombre de lignes de vol
%          LineSep : Sparation entre 2 lignes de vol
%               LV : Ligne de vol a considrer (1,2,3,4)
% outputs :    DBX : dbx/dt total (nT/s)
%              DBZ : dbz/dt total (nT/s)
%              dbx : dbx/dt plaque (nT/s)
%              dbz : dbz/dt plaque (nT/s)
%
% Maxime Claprood
%
filein=['model',int2str(modele),'.amx']; 
[fid,mesg]=fopen([repertoire,'/',filein],'r');
if (fid<0), return, end;
temp=readuntil(fid,'TIMES(ms)=');
temp=fgetl(fid);
bz=fscanf(fid,'%f %f %f %f %f %f %s %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f',[NbCol NbRg*NbLine])';
t=fgetl(fid);
bx=fscanf(fid,'%f %f %f %f %f %f %s %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f',[NbCol NbRg*NbLine])';
t=fgetl(fid);
by=fscanf(fid,'%f %f %f %f %f %f %s %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f',[NbCol NbRg*NbLine])';
t=fgetl(fid);
fclose(fid);
%
% Organise les donnes pour garder la ligne de vol souhaite
% Interpolation aux 2m
%
DBX=[];DBY=[];DBZ=[];
bx=bx(bx(:,5)==((LV-1)*LineSep),:);
bz=bz(bz(:,5)==((LV-1)*LineSep),:);
x=sqrt((bx(:,4)-bx(1,4)).^2);
X=[min(x):2:max(x)]';
bxint=interp1(x,bx(:,[10:end]),X,'spline');
bzint=interp1(x,bz(:,[10:end]),X,'spline');
DBX=[modele*ones(length(X),1) X zeros(length(X),1) bxint];
DBZ=[modele*ones(length(X),1) X zeros(length(X),1) bzint];
%
% Garder la rponse de la plaque seule en enlevant une mdiane
%
medx=median(DBX([1:20,end-20:end],[4:end]));
medz=median(DBZ([1:20,end-20:end],[4:end]));
un=ones(length(DBX),1);
dbx=[DBX(:,[1:3]) DBX(:,[4:end])-(un*medx)];
dbz=[DBZ(:,[1:3]) DBZ(:,[4:end])-(un*medz)];
