function [a,repertoire]=openparameters(No,NoiseLevel,Freq,TestouMod)
%
% function [a,repertoire]=openparameters(No,NoiseLevel,Freq)
%
% Ouvrir le fichier contenant les parametres des modeles gnriques ("parameters.txt")
% input  :         No : Nombre de modeles dans le fichier de parametres tests
%          NoiseLevel : Facteur ajustant le niveau de bruit par rapport au fichier original
%                Freq : Frquence d'mission du MEGATEM (30 ou 90)
%           TestouMod : 0 si modeles servant pour la rgression, 1 si modeles a tester
% output :          a : Structure comprenant les champs
%                   .paraName : Nom des parametres
%                       .para : Valeurs des parametres pour les 2100 modeles
%                  .TimeOnOff : Temps on, temps mort, dure du signal
%                     .TimeCh : Dbut, fin, interval et milieu des canaux de temps
%                 .TimeChName : Entete des colonnes du fichier de temps
%                      .bruit : Niveau de bruit du MEGATEM estim par les levs en Abitibi
%          repertoire : Nom du rpertoire contenant les donnes
%
% Maxime Claprood
%
%
if TestouMod==0
    filein1=('parameters');
    repertoire=('Models');
    No=2100;
else
    filein1=('paraTests');
    repertoire=('ModelesTests');
end
%
% Frquence d'mission
%
if Freq==90
    a.TimeOnOff = [2.36 3.20 5.56];
    filein2=('megatem90');
    filein3=('BruitMegatem90');
elseif Freq==30
    a.TimeOnOff = [4.023 12.643 16.666];
    filein2=('megatem30');
    filein3=('BruitMegatem30');
else
    Message='Pas une frquence d`mission du MEGATEM'
    break;
end
%
% Ouvre le fichier de parametres
%
[fid1,mesg1] = fopen([filein1,'.txt'],'r');
if (fid1<0), return, end;
a.paraName=char('Nom','Longueur','Extension','Profondeur','Conductance','Pendage','Taille');
a.para=fscanf(fid1,'%g',[6 No]);
a.para=a.para';
a.para(:,7)=a.para(:,2).*a.para(:,3);
fclose(fid1);
%
% Ouvre le fichier de temps du MEGATEM ("megatem90.txt" ou "megatem30.txt")
%
[fid2,mesg2] = fopen([filein2,'.txt'],'r');
if (fid2<0), return, end;
a.TimeCh=fscanf(fid2,'%g',[4 20]);
a.TimeCh = a.TimeCh';
a.TimeChName=char('TempsDebut','TempsFin','Intervalle','TempsMilieu');
fclose(fid2);
%
% Ouvre le fichier de bruit MEGATEM en Abitibi ("BruitMegatem90" ou "BruitMegatem30")
%
[fid3,mesg3] = fopen([filein3,'.txt'],'r');
if (fid3<0), return, end;
a.bruit=fscanf(fid3,'%g',[2 20]);
a.bruit = NoiseLevel*a.bruit';