% ClassPara2
%
% Estimer les proprits des modeles numriques avec les attributs calculs sur les levs MEGATEM
% Utilise les modeles de rgression multi-linaire
% Les attributs doivent etre calculs par le script MEGATEM pour avoir le bon format de donnes 
% Les proprits proviennent des rgressions effectues dont les rsultats sont dans les fichiers .mat
% WWDIP, WWZ1, WWZ2, WWZ3, WWST1, WWST2, WWST3, WWSIZE1, WWSIZE2 et WWSIZE3
%
% Maxime Claprood
%
%
% Initialisation des variables
%
clear; close all;
LimDip=[85 95];
x1=[];x2=[];x3=[];x4=[];
%
Type = input('Entrez le type de fichier a traiter : \n \n1 : Plaques minces numriques \n2 : Prismes \n3 : 30Hz \n4 : Ligne de vol excentre \n5 : Donnes relles de VMS \n\n');
if Type ==4
    Ligne = input('Entrez la ligne de vol a traiter : ');
end
%
% Numro des modeles a estimer les proprits
% Indiquer dans No la liste des modeles a estimer les proprits
%
switch Type
    case 1
    % Modles gnriques 
        No=[10135;10145;10136;10161;10171;10162;10239;10249;10240;10265;10275;10266;10291;10301;10292;10317;10327;10318;10343;10353;10344;10369;10379;10370;10447;10457;10448;10473;10483;10474];
        load Tests
    case 2
    % Prismes
        No = [20001:20024]';
        load VMSdata
        [fid1,mesg1] = fopen(['Prismes.txt'],'r');
        if (fid1<0), return, end;
        Prisme=fscanf(fid1,'%g',[6 24]);
        Prisme=Prisme';
        Prisme(:,7)=90;
        Prisme(:,8)=Prisme(:,2).*Prisme(:,3);
        y=Prisme(:,[1,2,3,4,6,7,8]);
        fclose(fid1);
    case 3
    % Frquence 30Hz
        No = [10601:10621]';
        load Tests
    case 4
    % Lignes non-centres
        No = [10145;10171;10184;10249;10275;10288;10301;10327;10340;10353;10379;10392;10431;10444;10137;10163;10176;10241;10267;10280;10293;10319;10332;10345;10371;10384;10397;10423;10436;10138;10164;10177;10242;10268;10281;10294;10320;10333;10346;10372;10385;10398;10424;10437];
        load VMSdata
    case 5
    % Donnes relles de VMS
        No=[100,101,107]';
        load VMSdata;
        filein1=['VMSAbitibi']
        [fid1,mesg1] = fopen([filein1,'.txt'],'r');
        if (fid1<0), return, end;
        y=fscanf(fid1,'%g',[8 9]);
        y=y';
        y=y([1:8],:);     % Enlever Aldermac
        fclose(fid1);
end
%
% Garder les attributs des modeles spcifis par No
%
for i=1:size(No,1)
    x1=[x1;PPXtest(PPXtest(:,1)==No(i),:)];
    x2=[x2;PPZtest(PPZtest(:,1)==No(i),:)];
    x3=[x3;tauEEtest(tauEEtest(:,1)==No(i),:)];
    x4=[x4;DBXDBZtest(DBXDBZtest(:,1)==No(i),:)];
end
Xi=[x1(:,[1,3,4]) x2(:,[3,6:9]) x3(:,[3,6]) x4(:,[2])];
%
% Enveler les modeles dont les attributs ne sont pas bien estims
%
ind=find(sum(Xi(:,[2:end]),2)<1e6);
x1=x1(ind,:);
x2=x2(ind,:);
x3=x3(ind,:);
x4=x4(ind,:);
Xi=Xi(ind,:);
Xi(:,[3,5,6,7,8,9,11])=log(Xi(:,[3,5,6,7,8,9,11]));
%
% Garder la bonne ligne de vol si fichier en comprend plus d'1 (Type == 4 ou 5)
%
switch Type
    case 4
        Xi=[x1(x1(:,2)==Ligne,[1,3,4]) x2(x2(:,2)==Ligne,[3,6:9]) x3(x3(:,2)==Ligne,[3,6]) x4(x1(:,2)==Ligne,[2])];
        Xi(:,[3,5,6,7,8,9,11])=log(Xi(:,[3,5,6,7,8,9,11]));
    case 5
        for i=1:size(y,1)
            t1=x1(:,1)==y(i,1);
            t2=x1(:,2)==y(i,2);
            tt=and(t1,t2);
            XX(i,:)=Xi(tt,:);
        end
        Xi=XX([1,2,5,6,3,4,7,8],:);
        y=y([1,2,5,6,3,4,7,8],[1,3:end]);
    otherwise
end
Nombre=size(Xi,1);
axeX=[1:1:Nombre];
%
% Proprits des modeles pour afficher les comparaisons
% Proprits des Types 2 et 5 sont dja entres
%
if or(Type==5,Type==2)
else
    load Tests
    for i=1:size(Xi,1)
        y(i,:)=atest.para(atest.para(:,1)==Xi(i,1),:);
    end
    if and(Type==4,mod(Ligne,2)==0)
        y(:,6)=90-(y(:,6)-90);
    end
end
XiName=char('Modele','|Px1-Px2|','log(Px1/Px2)','|Pz1-Pz2|','log(Pz1/Pz2)','log(Pz1/Pz3)','log(Pz2/Pz3)','log|(Pz1-Pz2)/(Pz1-Pz3)|','log(tau)','Lambda EE','log((Px1-Px2)/(Pz1-Pz2))');
%
% Loader les fichiers contenant les rsultats des rgressions
%
load WWDIP; 
load WWZ1; load WWZ2; load WWZ3; 
load WWST1; load WWST2; load WWST3;
load WWSIZE1; load WWSIZE2; load WWSIZE3;
%
% Estimation du Pendage
%
b=wDip.intb;
DipEst(:,1)=Xi(:,1);
DipEst(:,3)=b(end,2)*ones(size(Xi,1),1)+b(1,2)*Xi(:,5)+b(2,2)*Xi(:,11)+b(3,2)*Xi(:,8);
[del]=int_conf(wDip,Xi,[5 11 8],1.645);
DipEst(:,2)=DipEst(:,3)-del; DipEst(:,4)=DipEst(:,3)+del;
%
% Estimation de la profondeur
%
ZEst(:,1)=Xi(:,1);
for i=1:size(DipEst,1)
    %
    % On spare dpendant du pendage estim
    %
	if DipEst(i,3)<LimDip(1)
        b=wz2.intb;
        ZEst(i,3)=b(end,2)+b(1,2)*Xi(i,4)+b(2,2)*Xi(i,2)+b(3,2)*Xi(i,9)+b(4,2)*Xi(i,10)+b(5,2)*Xi(i,7);
        [del]=int_conf(wz2,Xi(i,:),[4 9 10 2 7],1.645);
    elseif DipEst(i,3)>LimDip(2)
        b=wz3.intb;   
        ZEst(i,3)=b(end,2)+b(1,2)*Xi(i,4)+b(2,2)*Xi(i,9)+b(3,2)*Xi(i,10)+b(4,2)*Xi(i,7);
        [del]=int_conf(wz3,Xi(i,:),[4 9 10 7],1.645);
    else
        b=wz1.intb;
        ZEst(i,3)=b(end,2)+b(1,2)*Xi(i,10)+b(2,2)*Xi(i,4)+b(3,2)*Xi(i,2)+b(4,2)*Xi(i,9)+b(5,2)*Xi(i,11);
        [del]=int_conf(wz1,Xi(i,:),[10 4 9 2 11],1.660);
    end
    ZEst(i,2)=ZEst(i,3)-del; ZEst(i,4)=ZEst(i,3)+del;
end
%
% Estimation de la conductance
%
stEst(:,1)=Xi(:,1);
for i=1:size(DipEst,1)
    %
    % On spare dpendant du pendage estim
    %
	if DipEst(i,3)<LimDip(1)
        b=wst2.intb;
        stEst(i,3)=b(end,2)+b(1,2)*Xi(i,9)+b(2,2)*Xi(i,10)+b(3,2)*Xi(i,8)+b(4,2)*Xi(i,2);
        [del]=int_conf(wst2,Xi(i,:),[9 10 8 2],1.645);
	elseif DipEst(i,3)>LimDip(2)
        b=wst3.intb;
        stEst(i,3)=b(end,2)+b(1,2)*Xi(i,9)+b(2,2)*Xi(i,10)+b(3,2)*Xi(i,8);
        [del]=int_conf(wst3,Xi(i,:),[9 10 8],1.645);
    else
        b=wst1.intb;
        stEst(i,3)=b(end,2)+b(1,2)*Xi(i,9)+b(2,2)*Xi(i,2)+b(3,2)*Xi(i,10);
        [del]=int_conf(wst1,Xi(i,:),[9 2 10],1.660);
    end
    stEst(i,2)=stEst(i,3)-del; stEst(i,4)=stEst(i,3)+del;
end
stEst(:,[2,3,4])=exp(stEst(:,[2,3,4]));
%
% Estimation des dimensions
%
SizeEst(:,1)=Xi(:,1);
for i=1:size(DipEst,1)
    %
    % On spare dpendant du pendage estim
    %
	if DipEst(i,3)<LimDip(1)
        Xi(i,11)=Xi(i,11)^2;
        b=wsize2.intb;
        SizeEst(i,3)=b(end,2)+b(1,2)*Xi(i,10)+b(2,2)*Xi(i,4)+b(3,2)*Xi(i,3)+b(4,2)*Xi(i,11);
        [del]=int_conf(wsize2,Xi(i,:),[10 4 3 11],1.645);
	elseif DipEst(i,3)>LimDip(2)
        b=wsize3.intb;
        SizeEst(i,3)=b(end,2)+b(1,2)*Xi(i,10)+b(2,2)*Xi(i,4)+b(3,2)*Xi(i,5)+b(4,2)*Xi(i,8);
        [del]=int_conf(wsize3,Xi(i,:),[10 4 5 8],1.645);
    else
        Xi(i,11)=Xi(i,11)^2;
        b=wsize1.intb;
        SizeEst(i,3)=b(end,2)+b(1,2)*Xi(i,10)+b(2,2)*Xi(i,11)+b(3,2)*Xi(i,5);
        [del]=int_conf(wsize1,Xi(i,:),[10 11 5],1.660);
    end
    SizeEst(i,2)=SizeEst(i,3)-del; SizeEst(i,4)=SizeEst(i,3)+del;
end
SizeEst(:,[2,3,4])=exp(SizeEst(:,[2,3,4]));
%
% On rassemble le tout... et on met a 0 les estimations (-)
%
DipEst(DipEst<=0)=0;
ZEst(ZEst<=0)=0;
stEst(stEst<=0)=0;
SizeEst(SizeEst<=0)=0;
ParaEst=[Xi(:,1) ZEst(:,3) stEst(:,3) DipEst(:,3) SizeEst(:,3)];
%
% Affiche les graphiques des parametres estims et modlises ou rels
%
figure(1)
for i=1:size(Xi,1)
    subplot(221)
    plot(axeX(i),y(i,4),'b*')
    hold on
    plot(axeX(i)*ones(1,3),ZEst(i,[2:4]),'r-+')
    set(gca,'yDir','reverse')
    axis([axeX(1) axeX(end) 0 300]);
    ylabel('Profondeur (m)','fontweight','bold','fontsize',12)
    legend('Z modlise','Z estime',3)
    %
    subplot(222)
    plot(axeX(i),y(i,5),'b*')
    hold on
    plot(axeX(i)*ones(1,3),stEst(i,[2:4]),'r-+')
    axis([axeX(1) axeX(end) 0 300]);
    ylabel('Conductance (S)','fontweight','bold','fontsize',12)
    legend('\sigma{t} modlise','\sigma{t} estime',2)
    %
    subplot(223)
    plot(axeX(i),y(i,6),'b*')
    hold on
    plot(axeX(i)*ones(1,3),DipEst(i,[2:4]),'r-+')
    axis([axeX(1) axeX(end) 0 180]);
    xlabel('Identificateur du modele','fontweight','bold','fontsize',12);
    ylabel('Pendage (  )','fontweight','bold','fontsize',12)
    legend('Pendage modlis','Pendage estim',1)
    %
    subplot(224)
    plot(axeX(i),y(i,7),'b*')
    hold on
    plot(axeX(i)*ones(1,3),SizeEst(i,[2:4]),'r-+')
    axis([axeX(1) axeX(end) 1000 500000]);
    xlabel('Identificateur du modele','fontweight','bold','fontsize',12);
    ylabel('Taille (m)','fontweight','bold','fontsize',12)
    legend('Taille modlise','Taille estime',0)
end
set(figure(1),'Color',[1 1 1])
set(figure(1),'Position',[10 40 1000 650])
%print -depsc TestsLigne4