% WWDIP
%
% Stepw et rgression multi-linaire pour estimer le pendage (Dip)
% 1ere tape de classification (pendage pour tous les modeles)
%
% Maxime Claprood
%
%
% Initialisation des variables
%
clear; close all; 
load VARX;          % VARX contient les attributs des modeles
no1=1; no2=2100;    % Modeles a utiliser
noY=6;              % 6 = Dip
weight=1;           % 1: rgression pondre (WLS), sinon: rgression normale (OLS)
%
% Organise les donnes pour faire la rgression
%
PrepReg;
%
% Rgression pas-a-pas pour dterminer les variables significatives
%
[s]=stepw(y,[x(:,[2:end])]);
Signif=[4];
p=length(Signif);
%
% Rgression pondre avec les variables significatives
%
[bb,yc,e,sc,r2,s2b,rb]=Wregres(y,x(:,Signif+1),W,1);
Fish(2)=2.45;   % Table de Fisher (n>120 p=4, a=0.05)
t= 1.645;       % n>100, p=0.95
intb = [bb-(t*sqrt(diag(s2b))), bb, bb+(t*sqrt(diag(s2b)))];
bnorm=bb./sqrt(diag(s2b));
stdx=std(x(:,Signif+1));
bnormX=bb(1:end-1).*stdx';
[Signif' intb([1:end-1],:) bnorm(1:end-1) bnormX]
%
% Vrifier l'influence des observations
%
[influ]=INFLUENCE(y,x(:,Signif+1),W);
figure
plot(x(:,1),influ,'r+')
title(['Influence des observations',a.paraName(noY,:)],'fontweight','bold','fontsize',14)
xlabel('Model id','fontweight','bold','fontsize',12);ylabel('Influence','fontweight','bold','fontsize',12);
%
% Enlever les observations trop influentes sur la rgression
% Dans littrature, on prend Di=1, Marcotte prend Di=0.5...
% Pas de valeur >0.5 mais semble y avoir des valeurs qui sont hors-norme
% J'enleve les modeles avec Di > 3*std(influ)
%
j=find(influ<3*std(influ));
xx=x(j,:);
yy=y(j,:);
WW=W(j,j);
% 
% Refaire la rgression pas-a-pas avec les modeles mieux estims
%
[s2]=stepw(yy,[xx(:,[2:end])]);
Signif2=[4 10 7];
p2=length(Signif2);
%
% Refaire rgression pondre avec les modeles mieux estims
%
[bb2,yc2,e2,sc2,r22,s2b2,rb2]=Wregres(yy,xx(:,Signif2+1),WW,1);
Fish2=2.68;   % Table de Fisher (n>120 p2=3, a=0.05)
t2= 1.645;       % n>100, p=0.95
intb2 = [bb2-(t2*sqrt(diag(s2b2))), bb2, bb2+(t2*sqrt(diag(s2b2)))];
bnorm2=bb2./sqrt(diag(s2b2));
stdx2=std(x(:,Signif2+1));
bnormX2=bb2(1:end-1).*stdx2';
bnormX2=[bnormX2;0];
[Signif2' intb2([1:end-1],:) bnorm2(1:end-1) bnormX2(1:end-1)]
GraphReg(xx,yy,yc2,e2,a,noY,xName);
% %
% % Garder les parametres finaux de la rgression du pendage
% %
% wDip.Signif=[xName(Signif2+1,:)];
% wDip.Name=xName;
% wDip.s=s2;
% wDip.x=xx;
% wDip.y=yy;
% wDip.yc=yc2;
% wDip.w=diag(WW);
% wDip.e=e2;
% wDip.intb=intb2;
% wDip.bnorm=[bnorm2 bnormX2];
% wDip.r2=r22;
% save WWDIP wDip
