% Wsize
% Stepw et rgression multi-linaire pour estimer la taille (DipExt * StrikeExt)
%
% Maxime Claprood
%
%
% Initialisation des variables
%
clear; close all;
load VARX;              % VARX contient les attributs des modeles
no1=1201; no2=2100;         % Intervalle des modeles a utiliser
noY=7;                  % 7 = Size
weight=1;               % 1: rgression pondre, sinon: rgression normale
%
% Organise les donnes pour faire la rgression
%
PrepReg;
y=log(y);
x(:,end)=x(:,end).^2;
%
% Rgression pas-a-pas pour dterminer les variables significatives
%
[s]=stepw(y,[x(:,[2:end])]);
%
% Garder les variables selon la classe de pendage (1: 90, 2: <90, 3: >90)
%
switch no1
    case 1
        Signif=[9 10 4];
    case 301
        Signif=[9 3 2 7 1];
    case 1201
        Signif=[9 3 4 7];
end
p=length(Signif);
%
% Rgression pondre avec les variables significatives
%
[bb,yc,e,sc,r2,s2b,rb]=Wregres(y,x(:,Signif+1),W,1);
t= 1.645;   % n>100, p=1, a=0.95
intb = [bb-(t*sqrt(diag(s2b))), bb, bb+(t*sqrt(diag(s2b)))];
bnorm=bb./sqrt(diag(s2b));
stdx=std(x(:,Signif+1));
bnormX=bb(1:end-1).*stdx';
[Signif' intb([1:end-1],:) bnorm(1:end-1) bnormX];
%
% Analyser l'influence des observations
%
[influ]=INFLUENCE(y,x(:,Signif+1),W);
figure
plot(x(:,1),influ,'r+')
title(['Influence des observations : ',a.paraName(noY,:)],'fontweight','bold','fontsize',14)
xlabel('Model id','fontweight','bold','fontsize',12);ylabel('Influence','fontweight','bold','fontsize',12);
%
% Enlever les observations trop influentes sur la rgression
%
j=find(influ<3*std(influ));
xx=x(j,:);
yy=y(j,:);
WW=W(j,j);
%
% Refaire la rgression pas-a-pas avec les modeles mieux estims
%
[s2]=stepw(yy,[xx(:,[2:end])]);
switch no1
    case 1
        Signif2=[9 10 4];          % Coefficients finaux pour size1
    case 301
        Signif2=[9 3 2 10];          % Coefficients finaux pour size2
    case 1201
        Signif2=[9 3 4 7];          % Coefficients finaux pour size3
end
p2=length(Signif2);
%
% Refaire rgression pondre avec les modeles mieux estims
%
[bb2,yc2,e2,sc2,r22,s2b2,rb2]=Wregres(yy,xx(:,Signif2+1),WW,1);
t2= 1.645;       % n>100, p=0.95
intb2 = [bb2-(t2*sqrt(diag(s2b2))), bb2, bb2+(t2*sqrt(diag(s2b2)))];
bnorm2=bb2./sqrt(diag(s2b2));
stdx2=std(x(:,Signif2+1));
bnormX2=bb2(1:end-1).*stdx2';
bnormX2=[bnormX2;0];
[Signif2' intb2([1:end-1],:) bnorm2(1:end-1) bnormX2(1:end-1)];
%
% Garder les parametres finaux de la rgression de la profondeur
% Crer un fichier par classe (1:90, 2: <90, 3: >90)
%
switch no1
    case 1
        wsize1.Name=xName;
        wsize1.Signif=[xName(Signif2+1,:)];
        wsize1.s=s2;
        wsize1.x=xx;
        wsize1.y=yy;
        wsize1.yc=yc2;
        wsize1.w=diag(WW);
        wsize1.e=e2;
        wsize1.intb=intb2;
        wsize1.bnorm=[bnorm2 bnormX2];
        wsize1.r2=r22;
        save WWSIZE1 wsize1    
    case 301
        wsize2.Name=xName;
        wsize2.Signif=[xName(Signif2+1,:)];
        wsize2.s=s2;
        wsize2.x=xx;
        wsize2.y=yy;
        wsize2.yc=yc2;
        wsize2.w=diag(WW);
        wsize2.e=e2;
        wsize2.intb=intb2;
        wsize2.bnorm=[bnorm2 bnormX2];
        wsize2.r2=r22;
        save WWSIZE2 wsize2
    case 1201
        wsize3.Name=xName;
        wsize3.Signif=[xName(Signif2+1,:)];
        wsize3.s=s2;
        wsize3.x=xx;
        wsize3.y=yy;
        wsize3.yc=yc2;
        wsize3.w=diag(WW);
        wsize3.e=e2;
        wsize3.intb=intb2;
        wsize3.bnorm=[bnorm2 bnormX2];
        wsize3.r2=r22;
        save WWSIZE3 wsize3
end
