% WWST
% Stepw et rgression multi-linaire pour estimer la conductance (st)
%
% Maxime Claprood
%
%
% Initialisation des variables
%
clear; close all;
load VARX;              % VARX contient les attributs des modeles
no1=1201; no2=2100;     % Intervalle des modeles a utiliser
noY=5;                  % 5 = st
weight=1;               % 1: rgression pondre (WLS), sinon: rgression normale (OLS)
%
% Organise les donnes pour faire la rgression
%
PrepReg;
y=log(y);
%
% Rgression pas-a-pas pour dterminer les variables significatives
%
[s]=stepw(y,[x(:,[2:end])]);
%
% Garder les variables selon la classe de pendage (1: 90, 2: <90, 3: >90)
%
switch no1
    case 1
        Signif=[8 1 9 2];
    case 301
        Signif=[8 9 7 1];
    case 1201
        Signif=[8 9 7];
end
p=length(Signif);
%
% Rgression pondre avec les variables significatives
%
[bb,yc,e,sc,r2,s2b,rb]=Wregres(y,x(:,Signif+1),W,1);
t= 1.645;   % n>100, p=1, a=0.95
intb = [bb-(t*sqrt(diag(s2b))), bb, bb+(t*sqrt(diag(s2b)))];
bnorm=bb./sqrt(diag(s2b));
stdx=std(x(:,Signif+1));
bnormX=bb(1:end-1).*stdx';
[Signif' intb([1:end-1],:) bnorm(1:end-1) bnormX];
%
% Analyser l'influence des observations
%
[influ]=INFLUENCE(y,x(:,Signif+1),W);
figure
plot(x(:,1),influ,'r+')
title(['Influence des observations : ',a.paraName(noY,:)],'fontweight','bold','fontsize',14)
xlabel('Model id','fontweight','bold','fontsize',12);ylabel('Influence','fontweight','bold','fontsize',12);
%
% Enlever les observations trop influentes sur la rgression
%
j=find(influ<3*std(influ));
xx=x(j,:);
yy=y(j,:);
WW=W(j,j);
%
% Refaire la rgression pas-a-pas avec les modeles mieux estims
%
[s2]=stepw(yy,[xx(:,[2:end])]);
switch no1
    case 1
        Signif2=[8 1 9];        % Coefficients finaux pour st1
    case 301
        Signif2=[8 9 7 1];      % Coefficients finaux pour st2
    case 1201
        Signif2=[8 9 7];        % Coefficients finaux pour st3
end
p2=length(Signif2);
%
% Refaire rgression pondre avec les modeles mieux estims
%
[bb2,yc2,e2,sc2,r22,s2b2,rb2]=Wregres(yy,xx(:,Signif2+1),WW,1);
t2= 1.645;       % n>100, p=0.95
intb2 = [bb2-(t2*sqrt(diag(s2b2))), bb2, bb2+(t2*sqrt(diag(s2b2)))];
bnorm2=bb2./sqrt(diag(s2b2));
stdx2=std(x(:,Signif2+1));
bnormX2=bb2(1:end-1).*stdx2';
bnormX2=[bnormX2;0];
[Signif2' intb2([1:end-1],:) bnorm2(1:end-1) bnormX2(1:end-1)];
%
% Garder les parametres finaux de la rgression de la profondeur
% Crer un fichier par classe (1:90, 2: <90, 3: >90)
%
switch no1
    case 1
        wst1.Name=xName;
        wst1.Signif=[xName(Signif2+1,:)];
        wst1.s=s2;
        wst1.x=xx;
        wst1.y=yy;
        wst1.yc=yc2;
        wst1.w=diag(WW);
        wst1.e=e2;
        wst1.intb=intb2;
        wst1.bnorm=[bnorm2 bnormX2];
        wst1.r2=r22;
        save WWST1 wst1    
    case 301
        wst2.Name=xName;
        wst2.Signif=[xName(Signif2+1,:)];
        wst2.s=s2;
        wst2.x=xx;
        wst2.y=yy;
        wst2.yc=yc2;
        wst2.w=diag(WW);
        wst2.e=e2;
        wst2.intb=intb2;
        wst2.bnorm=[bnorm2 bnormX2];
        wst2.r2=r22;
        save WWST2 wst2
    case 1201
        wst3.Name=xName;
        wst3.Signif=[xName(Signif2+1,:)];
        wst3.s=s2;
        wst3.x=xx;
        wst3.y=yy;
        wst3.yc=yc2;
        wst3.w=diag(WW);
        wst3.e=e2;
        wst3.intb=intb2;
        wst3.bnorm=[bnorm2 bnormX2];
        wst3.r2=r22;
        save WWST3 wst3
end
