% WWZ
% Stepw et rgression multi-linaire pour estimer la profondeur (z)
%
% Maxime Claprood
%
%
% Initialisation des variables
%
clear; close all;
load VARX;         % VARX contient les attributs des modeles
no1=1201; no2=2100;    % Intervalle des modeles a utiliser
noY=4;             % 4 = Depth
weight=1;          % 1: rgression pondre (WLS), sinon: rgression normale (OLS)
%
% Organise les donnes pour faire la rgression
%
PrepReg;
%
% Rgression pas-a-pas pour dterminer les variables significatives
%
[s]=stepw(y,[x(:,[2:end])]);
%
% Garder les variables selon la classe de pendage (1: 90, 2: <90, 3: >90)
%
switch no1
    case 1
        Signif=[9 3 8 1 10];
    case 301
        Signif=[3 8 9 1 6];
    case 1201
        Signif=[3 8 9 6 5 4];
end
p=length(Signif);
%
% Rgression pondre avec les variables significatives
%
[bb,yc,e,sc,r2,s2b,rb]=Wregres(y,x(:,Signif+1),W,1);
t= 1.645;   % n>100, p=1, a=0.95
intb = [bb-(t*sqrt(diag(s2b))), bb, bb+(t*sqrt(diag(s2b)))];
bnorm=bb./sqrt(diag(s2b));
stdx=std(x(:,Signif+1));
bnormX=bb(1:end-1).*stdx';
[Signif' intb([1:end-1],:) bnorm(1:end-1) bnormX];
%
% Analyser l'influence des observations
%
[influ]=INFLUENCE(y,x(:,Signif+1),W);
figure
plot(x(:,1),influ,'r+')
title(['Influence des observations : ',a.paraName(noY,:)],'fontweight','bold','fontsize',14)
xlabel('Model id','fontweight','bold','fontsize',12);ylabel('Influence','fontweight','bold','fontsize',12);
%
% Enlever les observations trop influentes sur la rgression
%
j=find(influ<3*std(influ));
xx=x(j,:);
yy=y(j,:);
WW=W(j,j);
%
% Refaire la rgression pas-a-pas avec les modeles mieux estims
%
[s2]=stepw(yy,[xx(:,[2:end])]);
switch no1
    case 1
        Signif2=[9 3 1 8 10];              % Coefficients finaux pour z1
    case 301
        Signif2=[3 1 8 9 6];              % Coefficients finaux pour z2
    case 1201
        Signif2=[3 8 9 6];              % Coefficients finaux pour z3
end
p2=length(Signif2);
%
% Refaire rgression pondre avec les modeles mieux estims
%
[bb2,yc2,e2,sc2,r22,s2b2,rb2]=Wregres(yy,xx(:,Signif2+1),WW,1);
t2= 1.645;       % n>100, p=0.95
intb2 = [bb2-(t2*sqrt(diag(s2b2))), bb2, bb2+(t2*sqrt(diag(s2b2)))];
bnorm2=bb2./sqrt(diag(s2b2));
stdx2=std(x(:,Signif2+1));
bnormX2=bb2(1:end-1).*stdx2';
bnormX2=[bnormX2;0];
[Signif2' intb2([1:end-1],:) bnorm2(1:end-1) bnormX2(1:end-1)];
%
% Garder les parametres finaux de la rgression de la profondeur
% Crer un fichier par classe (1:90, 2: <90, 3: >90)
%
switch no1
    case 1
        wz1.Name=xName
        wz1.Signif=[xName(Signif2+1,:)];
        wz1.s=s2;
        wz1.x=xx;
        wz1.y=yy;
        wz1.yc=yc2;
        wz1.w=diag(WW);
        wz1.e=e2;
        wz1.intb=intb2;
        wz1.bnorm=[bnorm2 bnormX2];
        wz1.r2=r22;
        save WWZ1 wz1
    case 301
        wz2.Name=xName;
        wz2.Signif=[xName(Signif2+1,:)];
        wz2.s=s2;
        wz2.x=xx;
        wz2.y=yy;
        wz2.yc=yc2;
        wz2.w=diag(WW);
        wz2.e=e2;
        wz2.intb=intb2;
        wz2.bnorm=[bnorm2 bnormX2];
        wz2.r2=r22;
        save WWZ2 wz2
    case 1201
        wz3.Name=xName;
        wz3.Signif=[xName(Signif2+1,:)];
        wz3.s=s2;
        wz3.x=xx;
        wz3.y=yy;
        wz3.yc=yc2;
        wz3.w=diag(WW);
        wz3.e=e2;
        wz3.intb=intb2;
        wz3.bnorm=[bnorm2 bnormX2];
        wz3.r2=r22;
        save WWZ3 wz3
end