% VMSdetect
%
% Permet la dtection d'anomalies sur un lev MEGATEM
% Utilise la mthode des statistiques d'ordre suprieur (variance courante)
%
% Maxime Claprood.
%
%
clear all; close all;
x=[];
%
% 1er et dernier canaux de temps pour les calculs
% Niveau de bruit a considrer (inscrire la fraction du niveau de bruit (=1 par dfaut))
%
Ch1=8;Ch2=20;
NoiseLevel=1;
NbCh=Ch2-Ch1+1;
% 
% Ouvre le fichier de parametres (Calcul du niveau de bruit et des canaux de temps)
%
[a]=openparameters(NoiseLevel);
%
% Ouvrir les fichiers de donnes (Choix selon le type de donnes a traiter)
%
DataType=input('Quel type de donnes traitez-vous : \n \n 1 = VMS Abitibi \n 2 = Autres VMS \n 3 = Modeles numriques \n')
switch DataType
    case 1
        modele=input('Inscrivez le numero du fichier a ouvrir \n \n Assurez-vous d`avoir insrer le CD contenant les donnes \n100: insco_bt1 \n101: insco_bt2 \n102: insco_btr \n103: insco_height1 \n104: insco_height2 \n105: insco_height3 \n106: insco_height4 \n107: gallen_bt1 \n108: gallen_bt2 \n109: aldermac_bt1 \n110: aldermac_bt2 \n \n');
        %
        % Ouvre le fichier de donnes MEGATEM du modele spcifi
        %
        [dbxdbz]=openAbitibi(modele);
        %
        % Traiter la ligne de vol dsir par l'usager
        %
        i=unique(dbxdbz(:,1));
        Message=['Lignes de vol disponibles : ', int2str(i')]
        L=input('Quelle ligne de vol voulez-vous traiter : ');
        %
        % Calcul des distances entre les points de mesure et le 1er point de mesure
        %
        X=dbxdbz(dbxdbz(:,1)==L,2);
        Y=dbxdbz(dbxdbz(:,1)==L,3);
        R=sqrt((X-X(1)).^2+(Y-Y(1)).^2);
        LL=size(R,1);
        %
        % x : Modele, Distance, Distance perpendiculaire a la ligne de vol (0), dbx/dt et dbz/dt de Ch1 a Ch2
        %
        x=[modele*ones(LL,1) R zeros(LL,1) dbxdbz(dbxdbz(:,1)==L,[Ch1-2:Ch2-2,Ch1+13:Ch2+13])];  
    case 2
        Where=['../Classification/DonneesTests'];
        modele=input('No du modele a analyser (9 modeles disponibles): ')
        %
        % Ouvre le fichier de donnes MEGATEM du modele spcifi
        %
        [dbxdbz]=openVMS(Where,modele);
        %
        % Traiter la ligne de vol dsir par l'usager
        %
        i=unique(dbxdbz(:,1));
        Message=['Lignes disponibles : ', int2str(i')]
        L=input('Quelle ligne de vol voulez-vous utiliser : ');
        %
        % Calcul des distances entre les points de mesure et le 1er point de mesure de la ligne de vol slectionne
        %
        X=dbxdbz(dbxdbz(:,1)==L,2);
        Y=dbxdbz(dbxdbz(:,1)==L,3);
        R=sqrt((X-X(1)).^2+(Y-Y(1)).^2);  % Calculer les distances (au lieu des positions)
        LL=size(R,1);
        %
        % x : Modele, Distance, Distance perpendiculaire a la ligne de vol (0), dbx/dt et dbz/dt de Ch1 a Ch2
        %
        x=[modele*ones(LL,1) R zeros(LL,1) dbxdbz(dbxdbz(:,1)==L,[Ch1-2:Ch2-2,Ch1+13:Ch2+13])];  
    case 3
        Where=['../Classification/ModeleTests'];
   		%
        % Modeles numriques a traiter, permet a l'usager de traiter plus d'un modele a la fois
        %
        Liste=input('Liste des modeles a traiter : \n (1 a 12, 10001 a 10620, 20001 a 20024, 30001 a 30072) \n Inscrire sous la forme  : [No1,No2,No3,No4...] \n ')
        %
        % Parametres initiaux des modeles numriques pour ouvrir les fichiers numriques .amx
        %
        NbCol=29;   % Tous les modeles ont 29 colonnes dans les fichiers .amx originaux
        NbPts=151*ones(1,size(Liste,2));    % La plupart des modeles numriques ont t construits avec 151 pts de mesure
        NbPts(and(Liste>3,Liste<13))=101;   % Certains modeles n'ont que 101 pts de mesures par ligne de vol
        NbPts(and(Liste>20000,Liste<30000))=101;
        NbLines=4*ones(1,size(Liste,2));    % La plupart des modeles numriques ont 4 lignes de vol
        NbLines(and(Liste>20000,Liste<30000))=1;    % Modeles numriques ayant seulement 1 ligne de vol
        NbLines(Liste<13)=1;
        Sep=150;    % Sparation entre les lignes de vol (150m)
        LL=(NbPts-1)*20;
        i=0;
        %
        % Ouvrir les fichiers .amx avec les parametres fixs
        %
        for modele=Liste
            i=i+1;
            [DBX,DBZ,dbx,dbz]=openEmGui(modele,Where,NbCol,NbPts(i),NbLines(i),Sep);
            toto=[DBX(1:end-1,[1:3,Ch1+3:Ch2+3]) DBZ(1:end-1,[Ch1+3:Ch2+3])];
            if i==1
                toto(:,2)=toto(:,2)+LL(i)/2+(i-1)*LL(i);
            else
                toto(:,2)=toto(:,2)+sum(LL(1:i-1))+LL(i)/2;
            end
            x=[x;toto];
            clear toto;
        end
end
%
% Calcul de la variance courante sur "No" points
%
No=20;
L=size(x,1)/No;
m2=[]; MOY=[];
for i=1:(floor(L)-1)*No+1           % Nombre d'intervalles de "No" points
    ii=floor(mean([i i+No-1]));     % Position milieu de l'intervalle
    C2=cum2(x([i:i+No-1],[4:end])); % Calcul du cumulant d'ordre 2 (variance courante)
    C2=[x(ii,2) C2];
    m2=[m2;C2];
end
%
% Calcul de la variance et cart-type globaux d'une ligne de vol
%
fact=1;         % Facteur pour comparaison entre variance courante et cart-type global d'une ligne de vol
VAR=var(x(:,[4:end]));
STD=std(x(:,[4:end]));
STDX=fact*ones(size(m2,1),1)*STD(1:NbCh);       % cart-type en dbx/dt
STDZ=fact*ones(size(m2,1),1)*STD(NbCh+1:end);   % cart-type en dbz/dt
%
% Comparer les variances courantes au bruit MEGATEM
%
noiseX=fact*ones(size(m2,1),1)*a.bruit([Ch1:Ch2],1)';
noiseZ=fact*ones(size(m2,1),1)*a.bruit([Ch1:Ch2],2)';
m2X=[m2(:,1) and(m2(:,[2:NbCh+1])>=noiseX,m2(:,[2:NbCh+1])>=STDX)];                 % Dtecteur en dbx/dt
m2Z=[m2(:,1) and(m2(:,[NbCh+2:2*NbCh+1])>=noiseZ,m2(:,[NbCh+2:2*NbCh+1])>=STDZ)];   % Dtecteur en dbz/dt
%
% Sommation a chaque position pour trouver le nombre de canaux dont m2 > bruit du MEGATEM
% et que m2 > cart-type de la ligne de vol
%
ixx=sum(m2X(:,[2:end]),2);      % # de canaux > Bruit en X
izz=sum(m2Z(:,[2:end]),2);      % # de canaux > Bruit en Z
IXX=1.25*(ixx>2);               % + de 3 canaux sont levs en X
IZZ=1.25*(izz>2);               % + de 3 canaux sont levs en Z
IXZ=1.25*and(IXX,IZZ);          % + de 3 canaux sont levs en X et Z simultanment
%
% Trouver les dbuts et fins des anomalies en X, Z et XZ
%
tplusx=find(diff(IXX)>0);
tmoinsx=find(diff(IXX)<0);
tplusz=find(diff(IZZ)>0);
tmoinsz=find(diff(IZZ)<0);
tplusxz=find(diff(IXZ)>0);
tmoinsxz=find(diff(IXZ)<0);
%
% Vrification si une anomalie est prsente sur le 1er ou dernier point d'une ligne de vol
%
if or(isempty(tplusx),isempty(tmoinsx))
else
    if tmoinsx(1)<tplusx(1)
        tplusx=[min(find(m2X(:,1)));tplusx];
    end
    if tplusx(end)>tmoinsx(end)
        tmoinsx=[tmoinsx;max(find(m2X(:,1)))];
    end
    ttx=[tplusx tmoinsx];
    LX=m2X(ttx(:,2),1)-m2X(ttx(:,1),1);
end
%
if or(isempty(tplusz),isempty(tmoinsz))
else
    if tmoinsz(1)<tplusz(1)
        tplusz=[min(find(m2Z(:,1)));tplusz];
    end
    if tplusz(end)>tmoinsz(end)
        tmoinsz=[tmoinsz;max(find(m2Z(:,1)))];
    end
    ttz=[tplusz tmoinsz];
    LZ=m2Z(ttz(:,2),1)-m2Z(ttz(:,1),1);
end
%
if or(isempty(tplusxz),isempty(tmoinsxz))
else
    if tmoinsxz(1)<tplusxz(1)
        tplusxz=[min(find(m2Z(:,1)));tplusxz];
    end
    if tplusxz(end)>tmoinsxz(end)
        tmoinsxz=[tmoinsxz;max(find(m2Z(:,1)))];
    end
    ttxz=[tplusxz tmoinsxz];
    LXZ=m2(ttxz(:,2),1)-m2(ttxz(:,1),1);
end
%
% Afficher graphiques des modeles calculs
% Ajuster les graphiques selon les donnes traites
%
% Figure 1 : Dtecteurs spars en dbx/dt et dbz/dt
%
figure(1)
set(figure(1),'Color',[1 1 1])
set(figure(1),'Position',[10 40 1000 650])
%
subplot(321)
plot(x(:,2),x(:,[4:NbCh+3]));
title('dbx/dt','fontweight','bold','fontsize',12)
ylabel('db/dt (nT/s)','fontweight','bold','fontsize',11)
axis([x(1,2) x(end,2) min(min(x(:,[4:NbCh+3]))) max(max(x(:,[4:NbCh+3])))])
%
subplot(323)
plot(m2(:,1),m2(:,[2:NbCh+1]))
ylabel('Variance courante','fontweight','bold','fontsize',11)
axis([x(1,2) x(end,2) 0 max(max(m2(:,[2:NbCh+1])))])
%
subplot(325)
plot(m2X(:,1),m2X(:,[2:NbCh+1]))
hold on
plot(m2X(:,1),IXX,'k-','Linewidth',3)
ylabel('Dtecteur','fontweight','bold','fontsize',11)
axis([x(1,2) x(end,2) -0.5 1.5])
%
subplot(322)
plot(x(:,2),x(:,[NbCh+4:2*NbCh+3]));
title('dbz/dt','fontweight','bold','fontsize',12)
axis([x(1,2) x(end,2) min(min(x(:,[NbCh+4:2*NbCh+3]))) max(max(x(:,[NbCh+4:2*NbCh+3])))])
%
subplot(324)
plot(m2(:,1),m2(:,[NbCh+2:end]))
axis([x(1,2) x(end,2) 0 max(max(m2(:,[NbCh+2:end])))])
%
subplot(326)
plot(m2Z(:,1),m2Z(:,[2:NbCh+1]))
hold on
plot(m2X(:,1),IZZ,'k-','Linewidth',3)
axis([x(1,2) x(end,2) -0.5 1.5])
%
% Figure 2 : Dtecteur conjoint en dbx/dt et dbz/dt simultanment
%
figure(2)
set(figure(2),'Color',[1 1 1])
set(figure(2),'Position',[10 40 1000 650])
%
subplot(311)
plot(x(:,2),x(:,[4:NbCh+3]));
ylabel('dbx/dt (nT/s)','fontweight','bold','fontsize',12)
axis([x(1,2) x(end,2) min(min(x(:,[4:NbCh+3]))) max(max(x(:,[4:NbCh+3])))])
%
subplot(312)
plot(x(:,2),x(:,[NbCh+4:2*NbCh+3]));
ylabel('dbz/dt (nT/s)','fontweight','bold','fontsize',12)
axis([x(1,2) x(end,2) min(min(x(:,[NbCh+4:2*NbCh+3]))) max(max(x(:,[NbCh+4:2*NbCh+3])))])
%
subplot(313)
plot(m2X(:,1),IXZ,'k-','Linewidth',3)
ylabel('Dtecteur','fontweight','bold','fontsize',12)
axis([x(1,2) x(end,2) -0.5 1.5])
%
% Sauvergarder les figures sous format .eps
%
% figure(1)
% print -depsc DetectXetZ9
% figure(2); 
% print -depsc DetectXZ9
