function [DBX,DBZ,dbx,dbz]=openEmGui(modele,repertoire,NbCol,NbRg,NbLine,LineSep)
%
% function [DBX,DBZ,dbx,dbz]=openEmGui(modele,repertoire,NbCol,NbRg,NbLine,LineSep)
%
% openEmGui : Ouvre le fichier de sortie provenant des logiciels de CSIRO
% inputs :  modele : No du modele a ouvrir
%       repertoire : Nom du rpertoire dans lequel sont les modeles 
%            NbCol : Nombre de colonnes du fichier EmGui
%             NbRg : Nombre de points de mesure d'une ligne de vol
%           NbLine : Nombre de lignes de vol
%          LineSep : Sparation entre 2 lignes de vol
% outputs :    DBX : dbx/dt total (nT/s)
%              DBZ : dbz/dt total (nT/s)
%              dbx : dbx/dt de la plaque seule (nT/s)
%              dbz : dbz/dt de la plaque seule(nT/s)
%
% Maxime Claprood
%
%
filein=['model',int2str(modele),'.amx']; 
[fid,mesg]=fopen([repertoire,'/',filein],'r');
if (fid<0), return, end;
temp=readuntil(fid,'TIMES(ms)=');
temp=fgetl(fid);
bz=fscanf(fid,'%f %f %f %f %f %f %s %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f',[NbCol NbRg*NbLine])';
t=fgetl(fid);
bx=fscanf(fid,'%f %f %f %f %f %f %s %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f',[NbCol NbRg*NbLine])';
t=fgetl(fid);
by=fscanf(fid,'%f %f %f %f %f %f %s %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f',[NbCol NbRg*NbLine])';
t=fgetl(fid);
fclose(fid);
%
% Organise les donnes pour garder la 1ere ligne de vol
%
bx=bx(bx(:,5)==0,[4,5,10:end]);
bz=bz(bz(:,5)==0,[4,5,10:end]);
un=ones(size(bx,1),1);
DBX=[modele*un bx];
DBZ=[modele*un bz];
%
% Garder la rponse de la plaque seule (enlever une mdiane)
%
medx=median(DBX([1:10,end-10:end],[4:end]));
medz=median(DBZ([1:10,end-10:end],[4:end]));
dbx=[DBX(:,[1:3]) DBX(:,[4:end])-(un*medx)];
dbz=[DBZ(:,[1:3]) DBZ(:,[4:end])-(un*medz)];