function [LEE]=VMSEE(modele,L,a,ind,EE);
%
% function [LEE]=VMSEE(modele,L,a,ind,EE);
% Permet a l'usager d'estimer la longueur d'onde de l'enveloppe d'nergie
%
% input : modele : Numro du modele
%              L : Ligne de vol slectionne
%              a : Structure contenant les parametres
%            ind : Canaux de temps dont Amplitude > bruit 
%             EE : EE pour la ligne de vol et les canaux 6 a 20
% output : EE : Longueur d'onde de l'EE
%
% Maxime Claprood
%
%
k=0;
moy=mean(a.bruit,2);
bruitEE=1/2*sqrt(moy.^2+real(hilbert(moy)).^2);
%
% On boucle sur tous les canaux de temps avec une amplitude assez forte
%
for j=ind
    k=k+1;
    figure(1)
    set(figure(1),'Position',[10 40 1000 650])
    plot([min(EE(:,1)) max(EE(:,1))],[bruitEE(j+5) bruitEE(j+5)],'k-' )
    hold on
    plot(EE(:,1),EE(:,j+1),'r-')
    title(['Champ EM total, Canal # ',int2str(j+5)],'fontweight','bold','fontsize',12)
    xlabel('distance de x0 (m)','fontweight','bold','fontsize',10)
    ylabel('Champ EM total (nT/s)','fontweight','bold','fontsize',10)
    text(max(EE(:,1)),max(EE(:,j+1)),'Cliquer le dbut et la fin de l`anomalie','HorizontalAlignment','right')
    %
    % "Picker" le dbut et la fin de l'EE
    % L'anomalie est mal dfinie, picker a droite de la zone de graphique
    %
    [xX,yX]=ginput(2);
    hold off;
    %
    % Calcul de la longueur d'onde de EE avec les slections
    %
    lee(k,1)=L;
    lee(k,2)=j;
    lee(k,3)=abs(xX(1)-xX(2));
    %
    % On met une valeur bidon si l'anomalie est mal dfinie pour un canal de temps
    %
    if sum(xX>max(EE(:,1)))>0
        lee(k,3)=1e6;
    end
end
%
% On garde les valeurs mdianes de l'EE
%
LEE(1)=modele;
LEE(2)=L;
LEE(3)=median(lee(lee(:,3)<1e6,3));