function [a,DBX,DBZ,PPX,PPZ,tauEE,DBXDBZ]=VMS_peaks(modele,dbxdbz,i)
%
% function [a,DBX,DBZ,PPX,PPZ,tauEE,DBXDBZ]=VMS_peaks(modele,dbxdbz,i)
% Utilise les donnes des fichiers MEGATEM pour calculer les attributs
% input : modele : Numro du modele
%         dbxdbz : dbx/dt et dbz/dt du modele pour toutes les lignes
%                  col 1     : Numro de ligne
%                  col 2-3   : Position en x et y
%                  col 4-18  : dbx/dt, canaux 6 a 20
%                  col 19-33 : dbz/dt, canaux 6 a 20
%              i : Lignes de vol disponibles
% output :     a : Structure contenant les parametres de vol
%            DBX : dbx/dt avec la mdiane enleve
%            DBZ : dbz/dt avec la mdiane enleve
%            PPX : Attributs calculs avec dbx/dt
%            PPZ : Attributs calculs avec dbz/dt
%          tauEE : Constantes de temps et longueur d'onde de l'EE
%         DBXDBZ : Attributs croiss entre dbx/dt et dbz/dt
%
% Maxime Claprood
%
%
Message=[' Lignes disponibles :', int2str(i')]
L=input('Quelle ligne voulez-vous utiliser : ');
Freq=input('Quelle frquence utilisez-vous (30Hz / 90Hz) : ');
NoiseLevel=1;
%
% Ouvrir le fichier de parametres 
%
[a]=para_MEGATEM(Freq,NoiseLevel);
%
% Rorganiser les donnes (dbx, dbz, EE, amplitudes et bruit)
%
X=dbxdbz(dbxdbz(:,1)==L,2);     % Prendre la ligne de vol slectionne
Y=dbxdbz(dbxdbz(:,1)==L,3);
R=sqrt((X-X(1)).^2+(Y-Y(1)).^2);  % Calculer les distances (au lieu des positions)
dbx=[R dbxdbz(dbxdbz(:,1)==L,[4:18])];  
dbz=[R dbxdbz(dbxdbz(:,1)==L,[19:33])];
unX=ones(size(dbx,1),1)*median(dbx(:,[2:end]));     % Mdiane en dbx/dt
unZ=ones(size(dbz,1),1)*median(dbz(:,[2:end]));     % Mdiane en dbz/dt
DBX=[dbx(:,1) dbx(:,[2:end])-unX];
DBZ=[dbz(:,1) dbz(:,[2:end])-unZ];
AmpX=(max(dbx(:,2:end))-min(dbx(:,2:end)))';        % Amplitude en X
AmpZ=(max(dbz(:,2:end))-min(dbz(:,2:end)))';        % Amplitude en Z
indX=find(AmpX>a.bruit([6:end],1));
indZ=find(AmpZ>a.bruit([6:end],2));
ind=intersect(indX,indZ)';          % Indice des canaux de temps dont Amplitude > bruit
%
% Afficher les figures dbx/dt et dbz/dt pour avoir un premier coup d'oeil
%
figure(1)
set(figure(1),'Position',[10 40 1000 650])
subplot(211)
plot(dbx(:,1),dbx(:,[2:16]))
title(['dbx/dt (nT/s)'],'fontweight','bold','fontsize',14)
ylabel('anomaly + background (nT/s)','fontweight','bold','fontsize',12')
subplot(212)
plot(DBX(:,1),DBX(:,[2:16]))
xlabel('distance from x0 (m)','fontweight','bold','fontsize',12')
ylabel('anomaly only (nT/s)','fontweight','bold','fontsize',12')
%
figure(2)
set(figure(2),'Position',[10 40 1000 650])
subplot(211)
plot(dbz(:,1),dbz(:,[2:16]))
title(['dbz/dt (nT/s)'],'fontweight','bold','fontsize',14)
ylabel('anomaly + background (nT/s)','fontweight','bold','fontsize',12')
subplot(212)
plot(DBZ(:,1),DBZ(:,[2:16]))
xlabel('distance from x0 (m)','fontweight','bold','fontsize',12')
ylabel('anomaly only (nT/s)','fontweight','bold','fontsize',12')
%
% L'usager doit appuyer sur une touche pour continuer
%
pause
close all;
%
% Prciser la zone d'intret pour plus de prcision dans le picking des attributs
%
figure(1)
set(figure(1),'Position',[10 40 1000 650])
subplot(211)
plot(DBX(:,1),DBX(:,[2:16]))
title(['dbx/dt and dbz/dt Profiles'],'fontweight','bold','fontsize',14)
ylabel('dbx/dt (nT/s)','fontweight','bold','fontsize',12)
text(max(DBX(:,1)),max(max(DBX(:,[2:16]))),'Select an area where to analyse the anomaly','HorizontalAlignment','right')
subplot(212)
plot(DBZ(:,1),DBZ(:,[2:16]))
ylabel('dbz/dt (nT/s)','fontweight','bold','fontsize',12)
xlabel('distance from x0 (m)','fontweight','bold','fontsize',12)
[x y]=ginput(2);
close all;
%
% Garder les donnes (dbx/dt et dbz/dt) dans la zone slectionne
%
ind2(1)=find(abs(dbx(:,1)-x(1))==min(abs(dbx(:,1)-x(1))));
ind2(2)=find(abs(dbx(:,1)-x(2))==min(abs(dbx(:,1)-x(2))));
DBX=DBX([ind2(1):ind2(2)],:);
DBZ=DBZ([ind2(1):ind2(2)],:);
EE=[DBX(:,1) sqrt(DBX(:,[2:end]).^2+DBZ(:,[2:end]).^2)];
%
% Calcul des attributs
%
[PPX]=peakDBX(modele,L,a,ind,DBX);
[PPZ]=peakDBZ(modele,L,a,ind,DBZ);
[LEE]=VMSEE(modele,L,a,ind,EE);
[tau]=VMStau(modele,L,a,DBZ);
tauEE=[tau LEE([2,3])];
DBXDBZ(1)=modele;
DBXDBZ(2)=PPX(3)/PPZ(3);
close all;
