function [tau]=VMStau(modele,L,a,dbz);
%
% function [tau]=VMStau(modele,L,a,dbz);
% Permet a l'usager de slectionner les points pour le calcul de tau
%
% input : modele : Numro du modele
%              L : Ligne de vol slectionne
%              a : Structure contenant les parametres
%            dbz : dbz/dt pour la ligne de vol et les canaux 6 a 20
% output : tau : Constante de temps estime par rgression
%
% Maxime Claprood
%
%
%
% Graphique de dbz/dt pour les canaux 8 a 20
%
figure(1)
set(figure(1),'Position',[10 40 1000 650])
plot(dbz(:,1),dbz(:,[4:end]))
title(['dbz/dt (nT/s), Ch #8 to #20'])
xlabel('distance de x0 (m)','fontweight','bold','fontsize',10)
ylabel('dbz/dt (nT/s)','fontweight','bold','fontsize',10)
text(max(dbz(:,1)),max(dbz(:,4)),'Ou voulez-vous estimer la constante de temps?','HorizontalAlignment','right')
%
% Slectionner ou doit se faire le calcul de la constante de temps
% Au maximum de dbz/dt sur le canal #8
%
[xt,yt]=ginput(1);
indt=find(abs(dbz(:,1)-xt)==min(abs(dbz(:,1)-xt)));
t=a.TimeCh([8:end],4)-a.TimeOnOff(1);
%
% Graph semi-log de dbz/dt en fonction du temps au point slectionn
%
figure(2)
set(figure(2),'Position',[10 40 1000 650])
semilogy(t,dbz(indt,[4:end]),'r+');
title('Courbe de dcroissance sur dbz/dt','fontweight','bold','fontsize',12)
xlabel('temps depuis coupure du courant (ms)','fontweight','bold','fontsize',10)
ylabel('dbz/dt (nT/s)','fontweight','bold','fontsize',10)
text(t(end),max(dbz(indt,:)),'Cliquez sur les donnes a utiliser pour estimer tau','HorizontalAlignment','right');
%
% Permet de slectionner les points a utiliser dans la rgression pour estimer tau
%
[t Z]=ginput(15);
hold on;
%
% Rgression linaire pour estimer la droite dont l'inverse reprsente tau
%
[b,yc,e,sc,r2,s2b,rb]=regres(log(Z),t,1);
%
% Affiche la droite estime
%
plot(t,exp(yc),'b*-')
pause
close all
%
% Rassemble l'information
%
tau(1)=modele;
tau(2)=L;
tau(3)=-1/b(1);
tau(4)=r2;