function [PPZ]=peakDBZ(modele,L,a,ind,dbz);
%
% function [PPZ]=peakDBZ(modele,L,a,ind,dbz);
% Permet a l'usager de "picker" les pics en dbz/dt pour le calcul des attributs en dbz/dt
%
% input : modele : Numro du modele
%              L : Ligne de vol slectionne
%              a : Structure contenant les parametres
%            ind : Canaux de temps dont Amplitude > bruit 
%            dbz : dbz/dt pour la ligne de vol et les canaux 6 a 20
% output : PPZ : Attributs en dbz/dt
%
% Maxime Claprood
%
%
k=0;
%
% On boucle sur tous les canaux de temps avec une amplitude assez forte
%
for j=ind
    k=k+1;
    figure(1)
    set(figure(1),'Position',[10 40 1000 650])
    plot([min(dbz(:,1)) max(dbz(:,1))],[a.bruit(j+5,2) a.bruit(j+5,2)],'k-' )
    hold on
    plot(dbz(:,1),dbz(:,j+1),'r-')
    title(['dbz/dt, Canal # ',int2str(j+5)],'fontweight','bold','fontsize',12)
    xlabel('distance de x0 (m)','fontweight','bold','fontsize',10)
    ylabel('dbz/dt (nT/s)','fontweight','bold','fontsize',10)
    text(max(dbz(:,1)),max(dbz(:,j+1)),'1er pic: celui de droite, 2e pic: celui de gauche, 3e pic: negatif au milieu','HorizontalAlignment','right')
    %
    % "Slectionner" les 3 pics (1er pic: droite, 2e pic: gauche, 3e pic: (-) au centre)
    % Si un pic n'est pas visible, cliquer a droite de la zone de graphique
    %
    [xZ,yZ]=ginput(3);
    hold off;
    %
    % Calcul des attributs avec les pics slectionns
    %
    ppz(k,1)=L;
    ppz(k,2)=j;
    ppz(k,3)=abs(xZ(1)-xZ(2));
    ppz(k,4)=abs(xZ(1)-xZ(3));
    ppz(k,5)=abs(xZ(2)-xZ(3));
    ppz(k,6)=abs(yZ(1)/yZ(2));
    ppz(k,7)=abs(yZ(1)/yZ(3));
    ppz(k,8)=abs(yZ(2)/yZ(3));
    ppz(k,9)=abs((xZ(1)-xZ(2))/(xZ(2)-xZ(3)));
    %
    % On met une valeur bidon si un pic n'existe pas
    %
    if sum(xZ(1)>max(dbz(:,1)))>0
        ppz(k,[3,4,6,7,9])=1e6;
    end
    if sum(xZ(2)>max(dbz(:,1)))>0
        ppz(k,[3,5,6,8,9])=1e6;
    end
    if sum(xZ(3)>max(dbz(:,1)))>0
        ppz(k,[4,5,7,8,9])=1e6;
    end
end
%
% On garde les valeurs mdianes des attributs
%
PPZ(1)=modele;
PPZ(2)=L;
PPZ(3)=median(ppz(ppz(:,3)<1e6,3));
PPZ(4)=median(ppz(ppz(:,4)<1e6,4));
PPZ(5)=median(ppz(ppz(:,5)<1e6,5));
PPZ(6)=median(ppz(ppz(:,6)<1e6,6));
PPZ(7)=median(ppz(ppz(:,7)<1e6,7));
PPZ(8)=median(ppz(ppz(:,8)<1e6,8));
PPZ(9)=median(ppz(ppz(:,9)<1e6,9));
close all